// -----------------------------------------------------------------------------
// File: waterworks_setup.ss
// Description: setup object for Waterworks Zone
// Author: Alexandre Martins <http://opensurge2d.org>
// License: MIT
// -----------------------------------------------------------------------------
using SurgeEngine.Lang;
using SurgeEngine.Level;
using SurgeEngine.Player;
using SurgeEngine.Vector2;
using SurgeEngine.Audio.Music;
using SurgeEngine.Audio.Sound;
using SurgeEngine.Events.EventList;
using SurgeEngine.Events.EventChain;
using SurgeEngine.Events.EntityEvent;
using SurgeEngine.Events.DelayedEvent;
using SurgeEngine.Events.FunctionEvent;

object "Sky High Setup"
{
    config = {

        //
        // all zones / acts
        //
        "*": {
            "Elevator": {
                "anim": 2
            },
            "Bridge": {
                "anim": 0
            },
            "Jumping Fish": {
                "anim": 1
            },
            "Audio Source": {
                "sound": "samples/waterfall.wav"
            },
            "Event Trigger 7": {
                "onTrigger": FunctionEvent("Lock Camera").withArgument(2048)
            }
        },

        //
        // zone 1 only
        //
        "1": {
            "Background Exchanger": {
                "background": "themes/skyhigh1norain.bg"
            },

            "Switch": {
                "onActivate": EventList([
                    FunctionEvent("Change Water Level").withArgument(9999999),
                    EntityEvent("Door").willCall("open"),
                    EntityEvent("Jumping Fish").willCall("destroy"),
                    EntityEvent("Skaterbug").willCall("destroy")
                ])
            },

            "Event Trigger 2": {
                "onTrigger": EventList([
                    EntityEvent("342f9e14298e755f").willCall("activate"),
                ])
            },

            "Event Trigger 7": {
                "onTrigger": EventList([
                    EntityEvent("Hydra").willCall("activate"),
                    FunctionEvent("Play Boss Music 3"),
                    FunctionEvent("Lock Camera").withArgument(640)
                ])
            },

            "Hydra": {
                "onDefeat": EventList([
                    FunctionEvent("Stop Boss Music 3"),
                    FunctionEvent("Lock Camera").withArgument(9999),
                    EntityEvent("dd0efcfb0f91fc8d").willCall("activate"),
                ])
            },

            "Goal": {
                "onDefeat": EventList([
                    FunctionEvent("Default Cleared Animation 2")
                ])
            },
        },

        //
        // zone 2 only
        //
        "2": {
            "Switch": {
                "onActivate": EntityEvent("Door").willCall("open")
            },

            "Event Trigger 1": {
                "onTrigger": EntityEvent("Dawn").willCall("fade")
            },

            // Bridge
            "48bacb13be3c2c0f": {
                "length": 20
            }
        }
    };

    // -------------------------------------------------------------------------

    state "main"
    {
    }

    // setup the entities
    fun constructor()
    {
        zone = String(Level.act);
        Level.setup(config["*"] || { });
        Level.setup(config[zone] || { });
    }
}
